==> libreoffice_24.2.7.orig.tar.xz: libreoffice-24.2.7.2/package/source/zippackage/wrapstreamforshare.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sal/config.h>
#include <sal/log.hxx>

#include <com/sun/star/io/IOException.hpp>
#include <utility>
#include <osl/diagnose.h>

#include "wrapstreamforshare.hxx"

using namespace ::com::sun::star;

#if OSL_DEBUG_LEVEL > 0
#define THROW_WHERE SAL_WHERE
#else
#define THROW_WHERE ""
#endif

WrapStreamForShare::WrapStreamForShare( uno::Reference< io::XInputStream > xInStream,
                                        rtl::Reference< comphelper::RefCountedMutex > xMutexRef )
: m_xMutex(std::move( xMutexRef ))
, m_xInStream(std::move( xInStream ))
, m_nCurPos( 0 )
{
    if ( !m_xMutex.is() || !m_xInStream.is() )
    {
        OSL_FAIL( "Wrong initialization of wrapping stream!" );
        throw uno::RuntimeException(THROW_WHERE );
    }
    m_xSeekable.set( m_xInStream, uno::UNO_QUERY_THROW );
}

WrapStreamForShare::~WrapStreamForShare()
{
}

// XInputStream
sal_Int32 SAL_CALL WrapStreamForShare::readBytes( uno::Sequence< sal_Int8 >& aData, sal_Int32 nBytesToRead )
{
    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    m_xSeekable->seek( m_nCurPos );

    sal_Int32 nRead = m_xInStream->readBytes( aData, nBytesToRead );
    m_nCurPos += nRead;

    return nRead;
}

sal_Int32 SAL_CALL WrapStreamForShare::readSomeBytes( uno::Sequence< sal_Int8 >& aData, sal_Int32 nMaxBytesToRead )
{
    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    m_xSeekable->seek( m_nCurPos );

    sal_Int32 nRead = m_xInStream->readSomeBytes( aData, nMaxBytesToRead );
    m_nCurPos += nRead;

    return nRead;
}

void SAL_CALL WrapStreamForShare::skipBytes( sal_Int32 nBytesToSkip )
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    m_xSeekable->seek( m_nCurPos );

    m_xInStream->skipBytes( nBytesToSkip );
    m_nCurPos = m_xSeekable->getPosition();
}

sal_Int32 SAL_CALL WrapStreamForShare::available()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    return m_xInStream->available();
}

void SAL_CALL WrapStreamForShare::closeInput()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    // the package is the owner so it will close the stream
    // m_xInStream->closeInput();
    m_xInStream.clear();
    m_xSeekable.clear();
}

// XSeekable
void SAL_CALL WrapStreamForShare::seek( sal_Int64 location )
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    // let stream implementation do all the checking
    m_xSeekable->seek( location );

    m_nCurPos = m_xSeekable->getPosition();
}

sal_Int64 SAL_CALL WrapStreamForShare::getPosition()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    return m_nCurPos;
}

sal_Int64 SAL_CALL WrapStreamForShare::getLength()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    return m_xSeekable->getLength();
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_26.2.0~rc1.orig.tar.xz: libreoffice-26.2.0.1/package/source/zippackage/wrapstreamforshare.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <sal/config.h>
#include <sal/log.hxx>

#include <com/sun/star/io/IOException.hpp>
#include <utility>
#include <osl/diagnose.h>

#include "wrapstreamforshare.hxx"

using namespace ::com::sun::star;

#if OSL_DEBUG_LEVEL > 0
#define THROW_WHERE SAL_WHERE
#else
#define THROW_WHERE ""
#endif

WrapStreamForShare::WrapStreamForShare( uno::Reference< io::XInputStream > xInStream,
                                        rtl::Reference< comphelper::RefCountedMutex > xMutexRef )
: m_xMutex(std::move( xMutexRef ))
, m_xInStream(std::move( xInStream ))
, m_nCurPos( 0 )
{
    if ( !m_xMutex.is() || !m_xInStream.is() )
    {
        OSL_FAIL( "Wrong initialization of wrapping stream!" );
        throw uno::RuntimeException(THROW_WHERE );
    }
    m_xSeekable.set( m_xInStream, uno::UNO_QUERY_THROW );
    mpByteReader = dynamic_cast<comphelper::ByteReader*>(m_xInStream.get());
    assert(mpByteReader);
}

WrapStreamForShare::~WrapStreamForShare()
{
}

// XInputStream
sal_Int32 SAL_CALL WrapStreamForShare::readBytes( uno::Sequence< sal_Int8 >& aData, sal_Int32 nBytesToRead )
{
    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    m_xSeekable->seek( m_nCurPos );

    sal_Int32 nRead = m_xInStream->readBytes( aData, nBytesToRead );
    m_nCurPos += nRead;

    return nRead;
}

sal_Int32 SAL_CALL WrapStreamForShare::readSomeBytes( uno::Sequence< sal_Int8 >& aData, sal_Int32 nMaxBytesToRead )
{
    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    m_xSeekable->seek( m_nCurPos );

    sal_Int32 nRead = m_xInStream->readSomeBytes( aData, nMaxBytesToRead );
    m_nCurPos += nRead;

    return nRead;
}

sal_Int32 WrapStreamForShare::readSomeBytes( sal_Int8* aData, sal_Int32 nMaxBytesToRead )
{
    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    m_xSeekable->seek( m_nCurPos );

    sal_Int32 nRead = mpByteReader->readSomeBytes( aData, nMaxBytesToRead );
    m_nCurPos += nRead;

    return nRead;
}

void SAL_CALL WrapStreamForShare::skipBytes( sal_Int32 nBytesToSkip )
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    m_xSeekable->seek( m_nCurPos );

    m_xInStream->skipBytes( nBytesToSkip );
    m_nCurPos = m_xSeekable->getPosition();
}

sal_Int32 SAL_CALL WrapStreamForShare::available()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    return m_xInStream->available();
}

void SAL_CALL WrapStreamForShare::closeInput()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    // the package is the owner so it will close the stream
    // m_xInStream->closeInput();
    m_xInStream.clear();
    m_xSeekable.clear();
    mpByteReader = nullptr;
}

// XSeekable
void SAL_CALL WrapStreamForShare::seek( sal_Int64 location )
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    // let stream implementation do all the checking
    m_xSeekable->seek( location );

    m_nCurPos = m_xSeekable->getPosition();
}

sal_Int64 SAL_CALL WrapStreamForShare::getPosition()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    return m_nCurPos;
}

sal_Int64 SAL_CALL WrapStreamForShare::getLength()
{
    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );

    if ( !m_xInStream.is() )
        throw io::IOException(THROW_WHERE );

    return m_xSeekable->getLength();
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
